@@ -30,16 +30,16 @@ class CollataAndPad(object):
             max_len = min(self.max_len, max([len(f['input_ids']) for f in features]))
 
         if self.shift_labels and not 'labels' in features[0]:
-            # Remove last element from each sample in input_ids
+            # Recalculate max_len
+            max_len = min(max_len, max([len(f['input_ids'][0:-1]) for f in features]))
+
+            # Labels do not exist and we should shift
+            batch['labels'] = torch.tensor([f['input_ids'][1:max_len+1] + [-100] * max(0, max_len - len(f['input_ids']) + 1)
+                                          for f in features], dtype=torch.long)
+
             for f in features:
                 f['input_ids'] = f['input_ids'][0:-1]
 
-            # Recalculate max_len
-            max_len = min(max_len, max([len(f['input_ids']) for f in features]))
-
-            # Labels do not exist and we should shift
-            batch['labels'] = torch.tensor([f['input_ids'][1:max_len] + [-100] * max(0, max_len - len(f['input_ids']) + 1)
-                                          for f in features], dtype=torch.long)
         elif 'labels' in features[0]:
             # Labels already exist, just pad them with -100
             batch['labels'] = torch.tensor([f['labels'] for f in features], dtype=torch.long)
